"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNative2 = require("@testing-library/react-native");
var _ChatConfigurationsContext = require("../../../../context/ChatConfigurationsContext");
var _ = _interopRequireDefault(require("."));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.mock('../../../../context/ChatConfigurationsContext');
const mockBotConfig = {
  chatConfigurations: {
    poweredBy: 'Mock powered by',
    poweredByUrl: 'https://mock.powered.com'
  }
};
describe('<Footer />', () => {
  it('renders text when poweredBy is present in botConfigs', () => {
    _ChatConfigurationsContext.useChatConfigurations.mockReturnValueOnce(mockBotConfig);
    const {
      getByText
    } = (0, _reactNative2.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const textElement = getByText(mockBotConfig.chatConfigurations.poweredBy);
    expect(textElement).toBeDefined();
  });
  it('does not render text when poweredBy is not present in botConfigs', () => {
    _ChatConfigurationsContext.useChatConfigurations.mockReturnValueOnce({
      botConfigs: {}
    });
    const {
      queryByText
    } = (0, _reactNative2.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const textElement = queryByText(mockBotConfig.chatConfigurations.poweredBy);
    expect(textElement).toBeNull();
  });
  it('calls Linking.openURL with poweredByUrl when text is pressed', () => {
    _ChatConfigurationsContext.useChatConfigurations.mockReturnValueOnce(mockBotConfig);
    const {
      getByTestId
    } = (0, _reactNative2.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const textElement = getByTestId('poweredBy');
    const mockOpenURL = jest.spyOn(_reactNative.Linking, 'openURL').mockImplementation(async () => {});
    _reactNative2.fireEvent.press(textElement);
    expect(mockOpenURL).toHaveBeenCalledWith(mockBotConfig.chatConfigurations.poweredByUrl);
    mockOpenURL.mockRestore();
  });
});
//# sourceMappingURL=index.spec.js.map