"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Code7Boteria = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _App = _interopRequireDefault(require("./App"));
var _global = require("./global");
var _utils = require("./utils");
var _infra = require("./infra");
var _MessageHttpSocketGateway = require("./gateways/MessageHttpSocketGateway");
var _ChatConfigurationsHttpGateway = require("./gateways/ChatConfigurationsHttpGateway");
var _SessionStorageGateway = require("./gateways/SessionStorageGateway");
var _NotificationRnGateway = require("./gateways/NotificationRnGateway");
var _UuidContext = _interopRequireDefault(require("./context/UuidContext"));
var _providers = require("./providers");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const Code7Boteria = _ref => {
  let {
    botId,
    params,
    appearance,
    children,
    staging
  } = _ref;
  const env = (0, _utils.getEnvironment)(staging);
  _global.Global.botId = botId;
  _global.Global.params = params;
  _global.Global.env = env;
  const logger = new _infra.ConsoleLoggerAdapter();
  const wsAdapter = new _infra.WebSocketAdapter(env.SOCKET_URL, logger);
  const axiosAdapterApi = new _infra.AxiosHttpConnectionAdapter(env.API_URL, logger);
  const axiosAdapterGetBot = new _infra.AxiosHttpConnectionAdapter(env.GET_BOT_URL, logger);
  const chatConfigurationsGateway = new _ChatConfigurationsHttpGateway.ChatConfigurationsHttpGateway(axiosAdapterGetBot);
  const storage = new _infra.EncryptedStorageAdapter();
  const sessionGateway = new _SessionStorageGateway.SessionStorageGateway(storage, axiosAdapterApi, wsAdapter);
  const messageGateway = new _MessageHttpSocketGateway.MessageHttpSocketGateway(wsAdapter, axiosAdapterApi, storage, sessionGateway);
  const notificationAdapter = new _infra.NotificationAdapter();
  const notificationGateway = new _NotificationRnGateway.NotificationRnGateway(notificationAdapter);
  const uuidAdapter = new _infra.MathUuidAdapter();
  wsAdapter.onOpen(async () => {
    await sessionGateway.linkSession();
  });
  return /*#__PURE__*/_react.default.createElement(_reactNative.KeyboardAvoidingView, {
    behavior: _reactNative.Platform.OS === 'ios' ? 'padding' : 'height'
  }, /*#__PURE__*/_react.default.createElement(_UuidContext.default, {
    uuid: uuidAdapter
  }, /*#__PURE__*/_react.default.createElement(_providers.SocketConnectionProvider, {
    ws: wsAdapter
  }, /*#__PURE__*/_react.default.createElement(_providers.ChatConfigurationsProvider, {
    configurations: chatConfigurationsGateway,
    appearance: appearance
  }, /*#__PURE__*/_react.default.createElement(_providers.SessionProvider, {
    sessionGateway: sessionGateway
  }, /*#__PURE__*/_react.default.createElement(_providers.MessageListProvider, {
    notificationGateway: notificationGateway,
    messageGateway: messageGateway
  }, /*#__PURE__*/_react.default.createElement(_App.default, {
    customWidget: children
  })))))));
};
exports.Code7Boteria = Code7Boteria;
//# sourceMappingURL=index.js.map