import React, { useState, useEffect } from 'react';
import { From, MessageTypes } from '../types';
import { useUuid } from '../context/UuidContext';
import MessageListContextProvider from '../context/MessageListContext';
import { MessageList } from '../entities/MessageList';
import { Observer } from '../entities/Observer';
export const MessageListProvider = _ref => {
  let {
    messageGateway,
    notificationGateway,
    children
  } = _ref;
  const {
    uuid
  } = useUuid();
  const [initialMessages, setInitialMessages] = useState(new MessageList([]));
  useEffect(() => {
    const fetchInitialMessages = async () => {
      const messages = await messageGateway.getMessages();
      messageGateway.onMessage(data => {
        messages.addMessage({
          ...data,
          id: data.id || uuid.generate(),
          from: From.BOT
        });
        if (data.type !== MessageTypes.TYPING) {
          notificationGateway.postLocal(data.message);
        }
      });
      messages.register(new Observer('clearMessages', async () => {
        setInitialMessages(await messageGateway.clearMessages());
      }));
      messages.register(new Observer('addMessage', async data => {
        if (data.type !== MessageTypes.TYPING) {
          if (data.from === From.USER) {
            setInitialMessages(await messageGateway.sendMessage(data));
          } else {
            await messageGateway.sendStatus(data.id, 'delivered');
            setInitialMessages(await messageGateway.storeMessage(data));
          }
        }
      }));
      setInitialMessages(messages);
    };
    fetchInitialMessages();
  }, []);
  return /*#__PURE__*/React.createElement(MessageListContextProvider, {
    initialMessageList: initialMessages
  }, children);
};
//# sourceMappingURL=MessageListProvider.js.map